package com.cool.bang.modules.mysql.domain;

import com.cool.bang.common.util.DateUtil;
import com.cool.bang.modules.oracle.domain.po.BhtTrade;
import com.cool.bang.modules.oracle.domain.po.HtInfo;
import org.apache.ibatis.type.Alias;
import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.util.List;

public class Contract {


    private static final long serialVersionUID = 1L;


    private Long id;

    /**
     * 合同编号
     */
    private String contractNumber;

    /**
     * 银行编号
     */
    private String bankCode;

    /**
     * 企业主键
     */
    private Integer orgId;

    /**
     * 企业名称
     */
    private String orgName;

    /**
     * 项目主键
     */
    private Long projectId;

    /**
     * 项目虚拟户主键
     */
    private Long projectAccountId;

    /**
     * 项目编号
     */
    private String projectNumber;

    /**
     * 项目名称
     */
    private String projectName;

    /**
     * 楼幢主键
     */
    private Integer buildingId;

    /**
     * 楼幢虚拟户主键
     */
    private Long buildingAccountId;

    /**
     * 楼幢编号
     */
    private String buildingNumber;

    /**
     * 楼幢名称
     */
    private String buildingName;

    /**
     * 房屋主键
     */
    private Long houseId;

    /**
     * 房屋坐落
     */
    private String houseAddress;

    /**
     * 房屋面积
     */
    private BigDecimal houseArea;

    /**
     * 房屋用途
     */
    private String houseUse;

    /**
     * 买受人
     */
    private String buyer;

    /**
     * 身份证号
     */
    private String idCard;

    /**
     * 付款方式 1一次性付款 2分期付款 3商业贷款 4公积金贷款 5组合贷款
     */
    private Integer payWay;

    /**
     * 合同价格
     */
    private BigDecimal contractPrice;

    /**
     * 首期款
     */
    private BigDecimal paymentAmount1;

    /**
     * 分期后期款
     */
    private BigDecimal paymentAmount2;

    /**
     * 商业贷款
     */
    private BigDecimal paymentAmount3;

    /**
     * 公积金贷款
     */
    private BigDecimal paymentAmount4;

    /**
     * 签订时间
     */
    private String signTime;

    /**
     * 收款银行
     */
    private String collectionBank;

    /**
     * 收款户名
     */
    private String collectionName;

    /**
     * 收款账号
     */
    private String collectionAccount;

    /**
     * 开户网点
     */
    private String collectionOpenAddress;

    /**
     * 收款账户主键
     */
    private Long accountId;

    /**
     * 账户类型 1托管账户 2监管账户
     */
    private Integer accountType;

    /**
     * 是否是抵工程款合同 0否 1是
     */
    private Integer isMortgage;

    /**
     * 是否退款 0否 1是
     */
    private Integer isRefund;

    /**
     * 是否有定金 0否 1是
     */
    private Integer isEarnest;

    /**
     * 是否撤销 0否 1是
     */
    private Integer isRescind;

    /**
     * 删除标识 1正常 0删除
     */
    private Integer delFlag;

    //是否逾期
    private Integer isOverdue;

    //交存状态 0 待缴存  1首期已交存  2交存完成或不需要交存
    private Integer paymentStatus;

    public Contract(HtInfo htInfo, BuildingAccount buildingAccount, Org org, P_lpb_fw fw, ProjectAccount projectAccount, List<BhtTrade> bhtTrades) {
        this.contractNumber = htInfo.getHTBH();
        this.orgId = org.getId();
        this.orgName = org.getOrgName();
        this.projectId = projectAccount.getProjectId();
        this.projectAccountId = projectAccount.getId();
        this.projectName = projectAccount.getProjectName();
        this.projectNumber = projectAccount.getProjectNumber();
        this.buildingId = buildingAccount.getBuildingId();
        this.buildingAccountId = buildingAccount.getId();
        this.buildingNumber = buildingAccount.getBuildingNumber();
        this.buildingName = buildingAccount.getBuildingName();
        if (null != fw) {
            this.houseAddress = fw.getXxdz();
            this.houseArea = fw.getJzmj();
            this.houseUse = fw.getYt();
            this.houseId = fw.getId();
        }
        this.buyer = htInfo.getBUYERNAME();
        this.idCard = htInfo.getBUYERCODE();
        this.payWay = getPayWat(htInfo.getPAYMODEL());
        this.contractPrice = htInfo.getHTZJ();
        this.signTime = null != htInfo.getHTDATE() ? DateUtil.dateToStr(htInfo.getHTDATE(), "yyyy-MM-dd HH:mm:ss") : null;
        this.accountType = StringUtils.isEmpty(htInfo.getJGLX()) ? null : Integer.valueOf(htInfo.getJGLX());
        this.accountId = null;
        this.bankCode = null;
        this.collectionOpenAddress = null;
        this.collectionAccount = null;
        this.collectionName = null;
        this.collectionBank = null;
        this.isMortgage = (!StringUtils.isEmpty(htInfo.getSGSTATE()) && "1".equals(htInfo.getSGSTATE())) ? 1 : 0;
        this.isRefund = (!StringUtils.isEmpty(htInfo.getTKSTATE()) && "1".equals(htInfo.getTKSTATE())) ? 1 : 0;
        this.isEarnest = null != htInfo.getHTDJ() ? 1 : 0;
        this.isRescind = (!StringUtils.isEmpty(htInfo.getCXSTATE()) && "1".equals(htInfo.getCXSTATE())) ? 1 : 0;
        this.delFlag = 1;
        this.isOverdue = (!StringUtils.isEmpty(htInfo.getYQFLAG()) && "1".equals(htInfo.getYQFLAG())) ? 1 : 0;
        if (null != bhtTrades && !bhtTrades.isEmpty()) {
            //交易总金额
            BigDecimal totalAmount = BigDecimal.ZERO;
/*            BhtTrade sfkTrade = bhtTrades.stream().filter(t -> null != t.getPayType() && t.getPayType().equals(1)).findFirst().orElse(null);
            BigDecimal sfk = null != sfkTrade ? sfkTrade.getJkje() : BigDecimal.ZERO;*/
            for (BhtTrade trade : bhtTrades) {
                if (null != trade.getTradeId() && null != trade.getTradeAmount()) {
                    totalAmount = totalAmount.add(trade.getTradeAmount());
                }
            }
            //交易明细的总金额 大于等于 合同的总金额  则
            if (totalAmount.compareTo(htInfo.getHTZJ()) > -1) {
                this.paymentStatus = 2;//交存完成或不需要交存
            } else if (totalAmount.compareTo(BigDecimal.ZERO) == 0) {
                this.paymentStatus = 0;//待交存
            } else {
                this.paymentStatus = 1;//首付款已交齐
            }
        } else {
            this.paymentStatus = 0;//待交存
        }
    }

    private Integer getPayWat(String paymodel) {
        switch (paymodel) {
            case "1"://商业贷款
                return 3;
            case "2"://公积金贷款
                return 4;
            case "3"://一次性付款
                return 1;
            case "4"://组合贷
                return 5;
            case "5"://其他
                return 6;
            default://分期
                return 2;
        }
    }


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContractNumber() {
        return contractNumber;
    }

    public void setContractNumber(String contractNumber) {
        this.contractNumber = contractNumber;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public Integer getOrgId() {
        return orgId;
    }

    public void setOrgId(Integer orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getProjectAccountId() {
        return projectAccountId;
    }

    public void setProjectAccountId(Long projectAccountId) {
        this.projectAccountId = projectAccountId;
    }

    public String getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(String projectNumber) {
        this.projectNumber = projectNumber;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Integer getBuildingId() {
        return buildingId;
    }

    public void setBuildingId(Integer buildingId) {
        this.buildingId = buildingId;
    }

    public Long getBuildingAccountId() {
        return buildingAccountId;
    }

    public void setBuildingAccountId(Long buildingAccountId) {
        this.buildingAccountId = buildingAccountId;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public String getBuildingName() {
        return buildingName;
    }

    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    public Long getHouseId() {
        return houseId;
    }

    public void setHouseId(Long houseId) {
        this.houseId = houseId;
    }

    public String getHouseAddress() {
        return houseAddress;
    }

    public void setHouseAddress(String houseAddress) {
        this.houseAddress = houseAddress;
    }

    public BigDecimal getHouseArea() {
        return houseArea;
    }

    public void setHouseArea(BigDecimal houseArea) {
        this.houseArea = houseArea;
    }

    public String getHouseUse() {
        return houseUse;
    }

    public void setHouseUse(String houseUse) {
        this.houseUse = houseUse;
    }

    public String getBuyer() {
        return buyer;
    }

    public void setBuyer(String buyer) {
        this.buyer = buyer;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public Integer getPayWay() {
        return payWay;
    }

    public void setPayWay(Integer payWay) {
        this.payWay = payWay;
    }

    public BigDecimal getContractPrice() {
        return contractPrice;
    }

    public void setContractPrice(BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }

    public BigDecimal getPaymentAmount1() {
        return paymentAmount1;
    }

    public void setPaymentAmount1(BigDecimal paymentAmount1) {
        this.paymentAmount1 = paymentAmount1;
    }

    public BigDecimal getPaymentAmount2() {
        return paymentAmount2;
    }

    public void setPaymentAmount2(BigDecimal paymentAmount2) {
        this.paymentAmount2 = paymentAmount2;
    }

    public BigDecimal getPaymentAmount3() {
        return paymentAmount3;
    }

    public void setPaymentAmount3(BigDecimal paymentAmount3) {
        this.paymentAmount3 = paymentAmount3;
    }

    public BigDecimal getPaymentAmount4() {
        return paymentAmount4;
    }

    public void setPaymentAmount4(BigDecimal paymentAmount4) {
        this.paymentAmount4 = paymentAmount4;
    }

    public String getSignTime() {
        return signTime;
    }

    public void setSignTime(String signTime) {
        this.signTime = signTime;
    }

    public String getCollectionBank() {
        return collectionBank;
    }

    public void setCollectionBank(String collectionBank) {
        this.collectionBank = collectionBank;
    }

    public String getCollectionName() {
        return collectionName;
    }

    public void setCollectionName(String collectionName) {
        this.collectionName = collectionName;
    }

    public String getCollectionAccount() {
        return collectionAccount;
    }

    public void setCollectionAccount(String collectionAccount) {
        this.collectionAccount = collectionAccount;
    }

    public String getCollectionOpenAddress() {
        return collectionOpenAddress;
    }

    public void setCollectionOpenAddress(String collectionOpenAddress) {
        this.collectionOpenAddress = collectionOpenAddress;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getIsMortgage() {
        return isMortgage;
    }

    public void setIsMortgage(Integer isMortgage) {
        this.isMortgage = isMortgage;
    }

    public Integer getIsRefund() {
        return isRefund;
    }

    public void setIsRefund(Integer isRefund) {
        this.isRefund = isRefund;
    }

    public Integer getIsEarnest() {
        return isEarnest;
    }

    public void setIsEarnest(Integer isEarnest) {
        this.isEarnest = isEarnest;
    }

    public Integer getIsRescind() {
        return isRescind;
    }

    public void setIsRescind(Integer isRescind) {
        this.isRescind = isRescind;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }

    public Integer getIsOverdue() {
        return isOverdue;
    }

    public void setIsOverdue(Integer isOverdue) {
        this.isOverdue = isOverdue;
    }

    public Integer getPaymentStatus() {
        return paymentStatus;
    }

    public void setPaymentStatus(Integer paymentStatus) {
        this.paymentStatus = paymentStatus;
    }
}
